/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.clipboard.button');

/**
 * Create the control instance.
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @class This class implements the behavior for an action.
 * @extends org.ametys.ribbon.control.RibbonControl
 */
org.ametys.odf.clipboard.button.PasteActionButton = function(id, configuration, pluginName)
{
    configuration['disabled'] = 'true';
	org.ametys.odf.clipboard.button.PasteActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.odf.clipboard.button.PasteActionButton, org.ametys.ribbon.control.button.ActionButton, {});

org.ametys.odf.clipboard.button.PasteActionButton_contentToCopy = null;

org.ametys.odf.clipboard.button.PasteActionButton.prototype.onMessage = function(messages)
{
    for (var i=0; i < messages.length; i++)
    {
        if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
        {
            var allTargets = messages[i].getTargets();
            var targets = org.ametys.messagebus.message.MessageTargetHelper.findAll(allTargets, this._testTarget.createDelegate(this));

            if (targets.length == 1 && org.ametys.odf.clipboard.button.PasteActionButton_contentToCopy != null)
            {
                // Current selected target is a valid target and there is a ODF content in clipboard
                this.updateTooltip(this.getConfiguration()["default-description"], null, null);
                this.getElements().each(function(element) { element.enable(); });
            }
            else
            {
                // Invalid current selection
                var text = this._getTooltip(this.getConfiguration()["no-selection-description"]);
		        this.updateTooltip(text, null, null);
                this.getElements().each(function(element) { element.disable(); });
            }
        }
        else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED)
        {
            var allTargets = messages[i].getTargets();
            var clipboardTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst(allTargets, function (target) { return target.getType() == 'odf-clipboard'});

            if (clipboardTarget)
            {
                var contentToCopy = clipboardTarget.getParameters().object;
			    if (contentToCopy == null)
                {
                    // There is no Program to copy in clipboard
                    org.ametys.odf.clipboard.button.PasteActionButton_contentToCopy = null;
                    this.getElements().each(function(element) { element.disable(); });
                    
                    var text = this._getTooltip(this.getConfiguration()["no-copy-description"]);
                    this.updateTooltip(text, null, null);
                    return false;
                }
                else
                {
                    // Save the content to copy, do enable the button yet, waiting for new selection
                    org.ametys.odf.clipboard.button.PasteActionButton_contentToCopy = contentToCopy;
                    this.updateTooltip(this.getConfiguration()["default-description"], null, null);
                }
            }
        }
    }
}

org.ametys.odf.clipboard.button.PasteActionButton.prototype._testTarget = function(target)
{
    return target.getType() == 'content' && (target.getParameters().type == 'org.ametys.plugins.odf.Content.program' 
        || target.getParameters().type == 'org.ametys.plugins.odf.Content.subProgram' 
        || target.getParameters().type == 'org.ametys.plugins.odf.Content.container'
    );
}

org.ametys.odf.clipboard.button.PasteActionButton.prototype._getTooltip = function (addedText)
{
    var tooltip = this.getConfiguration()["default-description"];
    if (addedText != null && addedText.length > 0)
    {
        tooltip += "<br/><br/>";
        tooltip += addedText;
    }
    return tooltip;
}